@@ -226,6 +226,17 @@ impl ClosedRange {
     }
 }
 
+impl fmt::Display for ClosedRange {
+    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
+        match self {
+            ClosedRange::To(to) => write!(f, "[0..{}[", to),
+            ClosedRange::ToInclusive(to) => write!(f, "[0..{}]", to),
+            ClosedRange::FromTo(from, to) => write!(f, "[{}..{}[", from, to),
+            ClosedRange::FromToInclusive(from, to) => write!(f, "[{}..{}]", from, to),
+        }
+    }
+}
+
 /// An open range
 ///
 /// An open range has no "defined end".
@@ -261,6 +272,15 @@ impl OpenRange {
     }
 }
 
+impl fmt::Display for OpenRange {
+    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
+        match self {
+            OpenRange::From(from) => write!(f, "[{}..]", from),
+            OpenRange::Full => write!(f, "[0..]"),
+        }
+    }
+}
+
 /// A range which specifies a download
 ///
 /// Conversions for the standard Rust range syntax exist.
@@ -337,6 +357,15 @@ impl DownloadRange {
     }
 }
 
+impl fmt::Display for DownloadRange {
+    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
+        match self {
+            DownloadRange::Open(open) => open.fmt(f),
+            DownloadRange::Closed(closed) => closed.fmt(f),
+        }
+    }
+}
+
 impl From<RangeFull> for DownloadRange {
     fn from(_: RangeFull) -> Self {
         Self::Open(OpenRange::Full)
